@@ -5,17 +5,22 @@ from fixedint.compat import *
 from weakref import WeakValueDictionary
 
 class FixedProperty(object):
-    def __init__(self, val):
+    def __init__(self, val, doc):
         self.val = val
+        self.__doc__ = doc
     def __get__(self, obj, type=None):
         return self.val
     def __set__(self, obj, value):
         raise AttributeError("property is read-only")
 
 class FixedMetaProperty(object):
-    def __init__(self, name):
+    def __init__(self, name, doc):
         self.name = name
+        self.__doc__ = doc
     def __get__(self, obj, type=None):
+        if self.name not in obj.__dict__:
+            # this should only happen when trying to access FixedInt.prop, which help() does
+            raise AttributeError("Attribute %s not defined on base class" % self.name)
         prop = obj.__dict__[self.name]
         return prop.__get__(obj)
     def __set__(self, obj, value):
@@ -29,6 +34,12 @@ if not PY3K:
 
 _class_cache = WeakValueDictionary()
 
+_doc_width = "Bit width of this integer, including the sign bit."
+_doc_signed = "True if this integer is a twos-complement signed type."
+_doc_mutable = "True if this integer is mutable (modifiable in-place)."
+_doc_minval = "Minimum representable value of this integer type"
+_doc_maxval = "Maximum representable value of this integer type"
+
 _subclass_token = object()
 class _FixedIntBaseMeta(type):
     def __new__(cls, name, bases, dict):
@@ -67,11 +78,11 @@ class _FixedIntBaseMeta(type):
             bases = (FixedInt, int)
 
         dict = {}
-        dict['width'] = FixedProperty(width)
-        dict['signed'] = FixedProperty(signed)
-        dict['mutable'] = FixedProperty(mutable)
-        dict['minval'] = FixedProperty(min)
-        dict['maxval'] = FixedProperty(max)
+        dict['width'] = FixedProperty(width, doc=_doc_width)
+        dict['signed'] = FixedProperty(signed, doc=_doc_signed)
+        dict['mutable'] = FixedProperty(mutable, doc=_doc_mutable)
+        dict['minval'] = FixedProperty(min, doc=_doc_minval)
+        dict['maxval'] = FixedProperty(max, doc=_doc_maxval)
 
         if signed:
             _mask1 = (1<<(width-1)) - 1
@@ -86,9 +97,13 @@ class _FixedIntBaseMeta(type):
 
         if not mutable:
             intbase = bases[1]
-            def _newfunc(cls, val=0):
+            def _newfunc(cls, val=0, base=None):
                 ''' Convert an integer into a fixed-width integer. '''
-                return intbase.__new__(cls, _rectify(int(val)))
+                if base is None:
+                    val = int(val)
+                else:
+                    val = int(val, base)
+                return intbase.__new__(cls, _rectify(val))
             _newfunc.__name__ = '__new__'
             dict['__new__'] = _newfunc
 
@@ -98,11 +113,11 @@ class _FixedIntBaseMeta(type):
         _class_cache[cachekey] = cls
         return cls
 
-    width = FixedMetaProperty('width')
-    signed = FixedMetaProperty('signed')
-    mutable = FixedMetaProperty('mutable')
-    minval = FixedMetaProperty('minval')
-    maxval = FixedMetaProperty('maxval')
+    width = FixedMetaProperty('width', doc=_doc_width)
+    signed = FixedMetaProperty('signed', doc=_doc_signed)
+    mutable = FixedMetaProperty('mutable', doc=_doc_mutable)
+    minval = FixedMetaProperty('minval', doc=_doc_minval)
+    maxval = FixedMetaProperty('maxval', doc=_doc_maxval)
 
 class _FixedIntMeta(_FixedIntBaseMeta):
     __new__ = type.__new__
@@ -300,7 +315,7 @@ class MutableFixedInt(FixedInt):
         return self
 
     def __setitem__(self, item, value):
-        ''' Modify a slice of aninteger.
+        ''' Modify a slice of an integer.
 
         x[a]=y sets a single bit at position a.
         x[a:b]=y sets a range of bits from an integer.
@@ -308,6 +323,7 @@ class MutableFixedInt(FixedInt):
         See __getitem__ for more details on the slice notation.
         '''
 
+        value = int(value)
         if isinstance(item, slice):
             start, stop = self._canonicalize_slice(item)
             mask = (1 << (stop - start)) - 1
@@ -446,7 +462,7 @@ globals()['_f'] = _f""" % op)
     return _f
 
 # pow is special because it takes three arguments.
-_inplace_func = 'add,+ sub,- mul,* truediv,/ floordiv,// mod,% lshift,<< rshift,<< and,& or,| xor,^'.split()
+_inplace_func = 'add,+ sub,- mul,* floordiv,// mod,% lshift,<< rshift,<< and,& or,| xor,^'.split()
 if not PY3K:
     _inplace_func += ['div,/']
 for f in _inplace_func:
